@@ -1,22 +1,47 @@
 import select
 import sys
-from typing import Union, Callable, Any, TYPE_CHECKING, no_type_check
-from arcor2.data.events import Event, PackageStateEvent, ActionStateEvent
-from arcor2.data.common import PackageStateEnum, ActionStateEnum, ActionState, PackageState
 from functools import wraps
+from typing import Any, Callable, TYPE_CHECKING, Union, no_type_check
+
+from arcor2.data.common import ActionState, ActionStateEnum, PackageState, PackageStateEnum
+from arcor2.data.events import ActionStateEvent, Event, PackageStateEvent
 
 HANDLE_ACTIONS = True
 
 if TYPE_CHECKING:
     from arcor2.object_types import Generic  # NOQA
-    from arcor2.services import Service  # NOQA
+    from arcor2.services.service import Service  # NOQA
 
 
-def read_stdin(timeout: float = 0.0) -> Union[str, None]:
+try:
+    # Windows solution
+    import msvcrt
+    import time
 
-    if select.select([sys.stdin], [], [], timeout)[0]:
-        return sys.stdin.readline().strip()
-    return None
+    def read_stdin(timeout: float = 0.0) -> Union[str, None]:
+
+        time_to_end = time.monotonic() + timeout
+
+        while True:
+
+            x = msvcrt.kbhit()  # type: ignore
+            if x:
+                return msvcrt.getch().decode()  # type: ignore
+
+            if not timeout or time.monotonic() > time_to_end:
+                return None
+
+            time.sleep(timeout/100.0)
+
+
+except ImportError:
+
+    # Linux solution
+    def read_stdin(timeout: float = 0.0) -> Union[str, None]:
+
+        if select.select([sys.stdin], [], [], timeout)[0]:
+            return sys.stdin.readline().strip()
+        return None
 
 
 def handle_action(inst: Union["Service", "Generic"], f: Callable[..., Any], where: ActionStateEnum) -> None:
