@@ -1,8 +1,8 @@
-from arcor2.data.common import Project, Scene, ProjectSources, IdDescList
-from arcor2.data.object_type import ObjectType, Models, Model3dType, Mesh, MeshList
+from arcor2 import persistent_storage
+from arcor2.data.common import IdDescList, Project, ProjectSources, Scene
+from arcor2.data.object_type import Mesh, MeshList, Model3dType, Models, ObjectType
 from arcor2.data.services import ServiceType
 from arcor2.helpers import run_in_executor
-from arcor2 import persistent_storage
 from arcor2.persistent_storage import PersistentStorageException  # noqa
 
 
@@ -22,6 +22,10 @@ async def put_model(model: Models) -> None:
     await run_in_executor(persistent_storage.put_model, model)
 
 
+async def delete_model(model_id: str) -> None:
+    await run_in_executor(persistent_storage.delete_model, model_id)
+
+
 async def get_projects() -> IdDescList:
     return await run_in_executor(persistent_storage.get_projects)
 
@@ -74,6 +78,10 @@ async def update_object_type(object_type: ObjectType) -> None:
     await run_in_executor(persistent_storage.update_object_type, object_type)
 
 
+async def delete_object_type(object_type_id: str) -> None:
+    await run_in_executor(persistent_storage.delete_object_type, object_type_id)
+
+
 async def update_service_type(service_type: ServiceType) -> None:
     await run_in_executor(persistent_storage.update_service_type, service_type)
 
