@@ -1,12 +1,13 @@
 # -*- coding: utf-8 -*-
 
+from dataclasses import dataclass, field
+from datetime import datetime
 from typing import List, Optional
 
-from dataclasses import dataclass, field
 from dataclasses_jsonschema import JsonSchemaMixin
 
-from arcor2.data.common import IdDesc, Position, ActionParameter, ActionIO, Orientation
-from arcor2.data.rpc.common import IdArgs, Request, Response, wo_suffix, RobotArg
+from arcor2.data.common import ActionIO, ActionParameter, IdDesc, Orientation, Position
+from arcor2.data.rpc.common import IdArgs, Request, Response, RobotArg, wo_suffix
 
 
 @dataclass
@@ -90,11 +91,11 @@ class OpenProjectResponse(Response):
 @dataclass
 class ListProjectsResponseData(IdDesc):
 
-    name: str = field(default_factory=str)
     scene_id: str = field(default_factory=str)
     valid: bool = field(default=False, metadata=dict(description="Objects and their actions exists."))
     executable: bool = field(default=False, metadata=dict(description="Logic is defined and valid."))
     problems: List[str] = field(default_factory=list)
+    modified: Optional[datetime] = None
 
 
 @dataclass
@@ -246,6 +247,7 @@ class UpdateActionPointParentRequestArgs(JsonSchemaMixin):
 class UpdateActionPointParentRequest(Request):
 
     args: UpdateActionPointParentRequestArgs
+    dry_run: bool = False
     request: str = field(default=wo_suffix(__qualname__), init=False)  # type: ignore  # noqa: F821
 
 
