@@ -1,12 +1,13 @@
 # -*- coding: utf-8 -*-
 
-from typing import List, Set
-
 from dataclasses import dataclass, field
+from datetime import datetime
+from typing import List, Optional, Set
+
 from dataclasses_jsonschema import JsonSchemaMixin
 
-from arcor2.data.common import IdDesc, SceneService, Pose
-from arcor2.data.rpc.common import IdArgs, Request, Response, wo_suffix, TypeArgs
+from arcor2.data.common import IdDesc, Pose, SceneService
+from arcor2.data.rpc.common import IdArgs, Request, Response, TypeArgs, wo_suffix
 
 
 @dataclass
@@ -150,10 +151,16 @@ class ListScenesRequest(Request):
     request: str = field(default=wo_suffix(__qualname__), init=False)  # type: ignore  # noqa: F821
 
 
+@dataclass
+class ListScenesResponseData(IdDesc):
+
+    modified: Optional[datetime] = None
+
+
 @dataclass
 class ListScenesResponse(Response):
 
-    data: List[IdDesc] = field(default_factory=list)
+    data: List[ListScenesResponseData] = field(default_factory=list)
     response: str = field(default=ListScenesRequest.request, init=False)
 
 
