@@ -2,25 +2,27 @@
 # -*- coding: utf-8 -*-
 
 
-from typing import Dict, Set, Union, Optional, DefaultDict, Any
 import os
 from collections import defaultdict
+from typing import Any, DefaultDict, Dict, Optional, Set
 
-from websockets.server import WebSocketServerProtocol as WsClient
 from aiologger import Logger  # type: ignore
 from aiologger.levels import LogLevel  # type: ignore
 
+from websockets.server import WebSocketServerProtocol as WsClient
+
 from arcor2 import helpers as hlp
-from arcor2.data.common import Scene, Project, PackageState, ActionState, CurrentAction
+from arcor2.data import events
+from arcor2.data.common import ActionState, CurrentAction, PackageState, Project, Scene
 from arcor2.data.execution import PackageInfo
 from arcor2.data.object_type import ObjectActionsDict, ObjectTypeMetaDict
-from arcor2.data.services import ServiceTypeMetaDict
 from arcor2.data.robot import RobotMeta
-from arcor2.object_types import Generic
-from arcor2.services import Service
-from arcor2.parameter_plugins.base import TypesDict
-from arcor2.nodes.execution import PORT as EXE_PORT
+from arcor2.data.services import ServiceTypeMetaDict
 from arcor2.nodes.build import PORT as BUILD_PORT
+from arcor2.nodes.execution import PORT as EXE_PORT
+from arcor2.object_types import Generic
+from arcor2.parameter_plugins.base import TypesDict
+from arcor2.services.service import Service
 
 logger = Logger.with_default_handlers(name='server', formatter=hlp.aiologger_formatter(), level=LogLevel.DEBUG)
 VERBOSE: bool = False
@@ -30,8 +32,10 @@ BUILDER_URL = os.getenv("ARCOR2_BUILDER_URL", f"http://0.0.0.0:{BUILD_PORT}")
 
 PORT: int = int(os.getenv("ARCOR2_SERVER_PORT", 6789))
 
-SCENE: Union[Scene, None] = None
-PROJECT: Union[Project, None] = None
+SCENE: Optional[Scene] = None
+PROJECT: Optional[Project] = None
+MAIN_SCREEN: Optional[events.ShowMainScreenData] = \
+    events.ShowMainScreenData(events.ShowMainScreenData.WhatEnum.ScenesList)
 
 INTERFACES: Set[WsClient] = set()
 
@@ -53,6 +57,7 @@ PACKAGE_STATE = PackageState()
 PACKAGE_INFO: Optional[PackageInfo] = None
 ACTION_STATE: Optional[ActionState] = None
 CURRENT_ACTION: Optional[CurrentAction] = None
+TEMPORARY_PACKAGE: bool = False
 
 RegisteredUiDict = DefaultDict[str, Set[WsClient]]
 
