@@ -1,6 +1,7 @@
 import abc
 from typing import FrozenSet
-from arcor2 import DynamicParamDict, CancelDict
+
+from arcor2 import CancelDict, DynamicParamDict
 from arcor2.docstring import parse_docstring
 
 
@@ -26,3 +27,10 @@ class Service(metaclass=abc.ABCMeta):
     @staticmethod
     def get_configuration_ids() -> FrozenSet[str]:
         return frozenset()
+
+    def cleanup(self) -> None:
+        """
+        This method is called when a scene is closed or when script ends.
+        :return:
+        """
+        pass
